<p align="center">
  <img src="https://www.labric.co/brand/snoot_goggles_bw.svg" alt="Labric Logo" width="100"/>
</p>

# Labric Python SDK

[Labric's](https://labric.co) official Python library - more functionality coming soon.

## Installation

```bash
# Using pip
pip install labric
```

## Usage

More details coming soon!
